==> fintecture-1.0.8.tar.gz: fintecture-1.0.8/fintecture/api_resources/abstract/api_resource.py <==
from __future__ import absolute_import, division, print_function

from fintecture import api_requestor, error, util, six
from fintecture.fintecture_object import FintectureObject
from fintecture.six.moves.urllib.parse import quote_plus


class APIResource(FintectureObject):
    @classmethod
    def retrieve(cls, id, app_id=None, **params):
        instance = cls(id, app_id, **params)
        instance.refresh()
        return instance

    def refresh(self):
        return self._request_and_refresh("get", self.instance_url())

    @classmethod
    def class_url(cls):
        if cls == APIResource:
            raise NotImplementedError(
                "APIResource is an abstract class.  You should perform "
                "actions on its subclasses (e.g. Charge, Customer)"
            )
        # Namespaces are separated in object names with periods (.) and in URLs
        # with forward slashes (/), so replace the former with the latter.
        base = cls.OBJECT_NAME.replace(".", "/")
        return "/v1/%ss" % (base,)

    def instance_url(self):
        id = self.get("id")

        if not isinstance(id, six.string_types):
            raise error.InvalidRequestError(
                "Could not determine which URL to request: %s instance "
                "has invalid ID: %r, %s. ID should be of type `str` (or"
                " `unicode`)" % (type(self).__name__, id, type(id)),
                "id",
            )

        id = util.utf8(id)
        base = self.class_url()
        extn = quote_plus(id)
        return "%s/%s" % (base, extn)

    # The `method_` and `url_` arguments are suffixed with an underscore to
    # avoid conflicting with actual request parameters in `params`.
    def _request(
        self,
        method_,
        url_,
        api_key=None,
        idempotency_key=None,
        fintecture_version=None,
        fintecture_account=None,
        headers=None,
        params=None,
    ):
        obj = FintectureObject._request(
            self,
            method_,
            url_,
            api_key,
            idempotency_key,
            fintecture_version,
            fintecture_account,
            headers,
            params,
        )

        if type(self) is type(obj):
            self.refresh_from(obj)
            return self
        else:
            return obj

    # The `method_` and `url_` arguments are suffixed with an underscore to
    # avoid conflicting with actual request parameters in `params`.
    def _request_and_refresh(
        self,
        method_,
        url_,
        app_id=None,
        idempotency_key=None,
        fintecture_version=None,
        fintecture_account=None,
        headers=None,
        params=None,
    ):
        obj = FintectureObject._request(
            self,
            method_,
            url_,
            app_id,
            idempotency_key,
            fintecture_version,
            fintecture_account,
            headers,
            params,
        )

        self.refresh_from(obj)
        return self

    # The `method_` and `url_` arguments are suffixed with an underscore to
    # avoid conflicting with actual request parameters in `params`.
    @classmethod
    def _static_request(
        cls,
        method_,
        url_,
        app_id=None,
        idempotency_key=None,
        fintecture_version=None,
        fintecture_account=None,
        params=None,
    ):
        params = None if params is None else params.copy()
        idempotency_key = util.read_special_variable(
            params, "idempotency_key", idempotency_key
        )
        fintecture_version = util.read_special_variable(
            params, "fintecture_version", fintecture_version
        )
        fintecture_account = util.read_special_variable(
            params, "fintecture_account", fintecture_account
        )
        fintecture_app_id = util.read_special_variable(
            params, "app_id", app_id
        )
        fintecture_app_secret = util.read_special_variable(
            params, "app_secret", None
        )
        fintecture_private_key = util.read_special_variable(
            params, "private_key", None
        )
        headers = util.read_special_variable(params, "headers", None)

        requestor = api_requestor.APIRequestor(
            app_id=fintecture_app_id,
            app_secret=fintecture_app_secret,
            private_key=fintecture_private_key,
            api_version=fintecture_version,
            account=fintecture_account
        )

        if idempotency_key is not None:
            headers = {} if headers is None else headers.copy()
            headers.update(util.populate_headers(idempotency_key))

        response, api_key = requestor.request(method_, url_, params, headers)
        return util.convert_to_fintecture_object(
            response, api_key, fintecture_version, fintecture_account, params
        )

    # The `method_` and `url_` arguments are suffixed with an underscore to
    # avoid conflicting with actual request parameters in `params`.
    @classmethod
    def _static_request_stream(
        cls,
        method_,
        url_,
        api_key=None,
        idempotency_key=None,
        fintecture_version=None,
        fintecture_account=None,
        params=None,
    ):
        params = None if params is None else params.copy()
        api_key = util.read_special_variable(params, "api_key", api_key)
        idempotency_key = util.read_special_variable(
            params, "idempotency_key", idempotency_key
        )
        fintecture_version = util.read_special_variable(
            params, "fintecture_version", fintecture_version
        )
        fintecture_account = util.read_special_variable(
            params, "fintecture_account", fintecture_account
        )
        headers = util.read_special_variable(params, "headers", None)

        requestor = api_requestor.APIRequestor(
            api_key, api_version=fintecture_version, account=fintecture_account
        )

        if idempotency_key is not None:
            headers = {} if headers is None else headers.copy()
            headers.update(util.populate_headers(idempotency_key))

        response, _ = requestor.request_stream(method_, url_, params, headers)
        return response

==> fintecture-1.2.0.tar.gz: fintecture-1.2.0/fintecture/api_resources/abstract/api_resource.py <==
from __future__ import absolute_import, division, print_function

from fintecture import api_requestor, error, util, six
from fintecture.fintecture_object import FintectureObject
from fintecture.six.moves.urllib.parse import quote_plus


class APIResource(FintectureObject):
    @classmethod
    def retrieve(cls, id, app_id=None, **params):
        instance = cls(id, app_id, **params)
        instance.refresh()
        return instance

    def refresh(self):
        return self._request_and_refresh("get", self.instance_url())

    @classmethod
    def class_url(cls):
        if cls == APIResource:
            raise NotImplementedError(
                "APIResource is an abstract class.  You should perform "
                "actions on its subclasses (e.g. Charge, Customer)"
            )
        # Namespaces are separated in object names with periods (.) and in URLs
        # with forward slashes (/), so replace the former with the latter.
        base = cls.OBJECT_NAME.replace(".", "/")
        return "/v1/%ss" % (base,)

    def instance_url(self):
        id = self.get("id")

        if not isinstance(id, six.string_types):
            raise error.InvalidRequestError(
                "Could not determine which URL to request: %s instance "
                "has invalid ID: %r, %s. ID should be of type `str` (or"
                " `unicode`)" % (type(self).__name__, id, type(id)),
                "id",
            )

        id = util.utf8(id)
        base = self.class_url()
        extn = quote_plus(id)
        return "%s/%s" % (base, extn)

    # The `method_` and `url_` arguments are suffixed with an underscore to
    # avoid conflicting with actual request parameters in `params`.
    def _request(
        self,
        method_,
        url_,
        app_id=None,
        fintecture_version=None,
        headers=None,
        params=None,
    ):
        obj = FintectureObject._request(
            self,
            method_,
            url_,
            app_id,
            fintecture_version,
            headers,
            params,
        )

        if type(self) is type(obj):
            self.refresh_from(obj)
            return self
        else:
            return obj

    # The `method_` and `url_` arguments are suffixed with an underscore to
    # avoid conflicting with actual request parameters in `params`.
    def _request_and_refresh(
        self,
        method_,
        url_,
        app_id=None,
        fintecture_version=None,
        headers=None,
        params=None,
    ):
        obj = FintectureObject._request(
            self,
            method_,
            url_,
            app_id,
            fintecture_version,
            headers,
            params,
        )

        self.refresh_from(obj)
        return self

    # The `method_` and `url_` arguments are suffixed with an underscore to
    # avoid conflicting with actual request parameters in `params`.
    @classmethod
    def _static_request(
        cls,
        method_,
        url_,
        app_id=None,
        fintecture_version=None,
        params=None,
    ):
        params = None if params is None else params.copy()
        fintecture_version = util.read_special_variable(
            params, "fintecture_version", fintecture_version
        )
        fintecture_app_id = util.read_special_variable(
            params, "app_id", app_id
        )
        fintecture_app_secret = util.read_special_variable(
            params, "app_secret", None
        )
        fintecture_private_key = util.read_special_variable(
            params, "private_key", None
        )
        headers = util.read_special_variable(params, "headers", None)

        requestor = api_requestor.APIRequestor(
            app_id=fintecture_app_id,
            app_secret=fintecture_app_secret,
            private_key=fintecture_private_key,
            api_version=fintecture_version,
        )

        response, my_app_id = requestor.request(method_, url_, params, headers)
        return util.convert_to_fintecture_object(
            response, my_app_id, fintecture_version, params
        )
